# eric7.WebBrowser.CookieJar.CookiesExceptionsDialog

Module implementing a dialog for the configuration of cookie exceptions.

### Global Attributes

None

### Classes

CookiesExceptionsDialog | Class implementing a dialog for the configuration of cookie exceptions.

### Functions

None

## CookiesExceptionsDialog

Class implementing a dialog for the configuration of cookie exceptions.

### Derived from

QDialog, Ui_CookiesExceptionsDialog

### Class Attributes

None

### Class Methods

None

### Methods

CookiesExceptionsDialog | Constructor
on_allowButton_clicked | Private slot to allow cookies of a domain.
on_allowForSessionButton_clicked | Private slot to allow cookies of a domain for the current session only.
on_blockButton_clicked | Private slot to block cookies of a domain.
on_domainEdit_textChanged | Private slot to handle a change of the domain edit text.
setDomainName | Public method to set the domain to be displayed.

### Static Methods

None

#### CookiesExceptionsDialog (Constructor)

CookiesExceptionsDialog(cookieJar, parent=None)

Constructor

cookieJar
  reference to the cookie jar (CookieJar)
parent
  reference to the parent widget (QWidget)

#### CookiesExceptionsDialog.on_allowButton_clicked

on_allowButton_clicked()

Private slot to allow cookies of a domain.

#### CookiesExceptionsDialog.on_allowForSessionButton_clicked

on_allowForSessionButton_clicked()

Private slot to allow cookies of a domain for the current session only.

#### CookiesExceptionsDialog.on_blockButton_clicked

on_blockButton_clicked()

Private slot to block cookies of a domain.

#### CookiesExceptionsDialog.on_domainEdit_textChanged

on_domainEdit_textChanged(txt)

Private slot to handle a change of the domain edit text.

txt
  current text of the edit (string)

#### CookiesExceptionsDialog.setDomainName

setDomainName(domain)

Public method to set the domain to be displayed.

domain
  domain name to be displayed (string)

Up